@@ -1,9 +1,10 @@
 #' Cross-sectional (contemporaneous) aggregation matrix
 #'
-#'
-#' This function allows the user to easily build the (\code{na x nb}) cross-sectional
-#' (contemporaneous) matrix mapping the \code{nb} bottom level series into the \code{na} higher level
-#' ones. (Experimental version)
+#' @description
+#' \loadmathjax
+#' This function allows the user to easily build the (\mjseqn{n_a \times n_b})
+#' cross-sectional (contemporaneous) matrix mapping the \mjseqn{n_b} bottom
+#' level series into the \mjseqn{n_a} higher level ones. (\emph{Experimental version})
 #'
 #' @param formula  Specification of the hierarchical structure: grouped hierarchies are specified
 #' using \code{~ g1 * g2} and nested hierarchies are specified using \code{~ parent / child}.
@@ -16,6 +17,9 @@
 #'
 #' @return A (\code{na x nb}) matrix.
 #'
+#' @keywords utilities
+#' @family utilities
+#'
 #' @examples
 #' ## Balanced hierarchy
 #' #         T
@@ -77,7 +81,7 @@
 #' @import Matrix
 Cmatrix <- function(formula, data, sep = "_", sparse = TRUE, top_label = "Total") {
   if (missing(data)) {
-    stop("The data parameter is required")
+    stop("The data parameter is required", call. = FALSE)
   }
 
   if (NCOL(data) == 1) {
